@@ -13,18 +13,10 @@ def capture(command):
     return out, err, proc.returncode
 
 
-# def command_extract_should_succeed():
-#     config_dirpath = tempfile.mkdtemp()
-#     breakpoint()
-#     _, err, returncode = capture(
-#         ["msgram", "extract", "-o", "sonarqube", "-cp", config_dirpath, "-dp", "sonar-output-fake"]
-#     )
-
-
 def test_extract_metrics_folder_not_found_exception_handling():
     config_dirpath = tempfile.mkdtemp()
     _, err, returncode = capture(
-        ["msgram", "extract", "-o", "sonarqube", "-cp", config_dirpath, "-dp", "sonar-output-fake"]
+        ["msgram", "extract", "-o", "sonarqube", "-ep", config_dirpath, "-dp", "sonar-output-fake"]
     )
 
     assert returncode == 1
@@ -35,8 +27,8 @@ def test_extract_metrics_folder_not_found_exception_handling():
 
 def test_extract_metrics_config_folder_not_found_exception_handling():
     msg, _, returncode = capture(
-        ["msgram", "extract", "-o", "sonarqube", "-cp", "config-fake", "-dp", "sonar-output-fake"]
+        ["msgram", "extract", "-o", "sonarqube", "-ep", "config-fake", "-dp", "sonar-output-fake"]
     )
 
     assert returncode == 1
-    assert "FileNotFoundError: config directory" in msg.decode("utf-8")
+    assert "FileNotFoundError: extract directory" in msg.decode("utf-8")
